@@ -110,9 +110,14 @@ test_that(
 
 test_that(
   "SchurCPP is correct", {
-    x <- as.bigq(c(6L,-7L,8L,9L), c(1L,2L,3L,4L))
+    x <- as.bigq(c(6L, -7L, 8L, 9L), c(1L, 2L, 3L, 4L))
     lambda <- c(3, 2)
     res <- SchurCPP(x, lambda)
     expect_identical(res, Schur(x, lambda))
+    #
+    x <- c(6, -7, 8, 9) / c(1, 2, 3, 4)
+    lambda <- c(3, 2)
+    res <- SchurCPP(x, lambda)
+    expect_equal(res, Schur(x, lambda))
   }
 )
